@@ -4,7 +4,7 @@ from random import randint,choice
 from os import system,urandom
 from termcolor import colored
 import f61d.LOGO as LOGO
-from f61d.__version__ import *
+from f61d.__version__ import __VERSION__
 
 
 __version__ == __VERSION__
@@ -20,7 +20,7 @@ help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
 help_cont[6] = 'Nim      : An interesting turtle game.'
 help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
-help_cont[8] - 'yinyang  : Draw the TaiJi.'
+help_cont[8] = 'yinyang  : Draw the TaiJi.'
 
 
 def Help(page=1,lines = 5):
@@ -48,7 +48,7 @@ def fuckStar():
 
     bar = trange(randint(1000,2000))
     for i in bar:
-        bar.set_description('Hacking:',hex(urandom(4))[2:])
+        bar.set_description('Hacking:'+hex(int.from_bytes(urandom(4),'big'))[2:])
         for _ in range(66666):
             a = 1
             b = 1
@@ -144,7 +144,7 @@ def yinyang():
     
     
 def main():
-    help()
+    Help()
     fuckStar()
     #r = prove('sha256(XXX + O3) = a289ace0c0301fba709365606da60acf11d793869a7c76083cef6c1ac6ff1396')
     #print(r)
